@@ -27,7 +27,7 @@ Common aliases for type hinting.
 #
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 #  GNU Lesser General Public License for more details.
 #
 #  You should have received a copy of the GNU Lesser General Public License
@@ -204,8 +204,7 @@ class String(Protocol):
 		Moved from :mod:`domdf_python_tools.stringlist`.
 	"""
 
-	def __str__(self) -> str:
-		...  # pragma: no cover
+	def __str__(self) -> str: ...
 
 
 @runtime_checkable
