@@ -12,7 +12,7 @@ General utility functions.
 	* Removed ``as_text`` and ``word_join``.
 	  Import from :mod:`domdf_python_tools.words` instead.
 	* Removed ``splitLen``.
-	  Use :func:`domdf_python_tools.utils.split_len` instead.
+	  Use :func:`domdf_python_tools.iterative.split_len` instead.
 
 .. versionchanged:: 2.0.0
 
@@ -22,6 +22,12 @@ General utility functions.
 	:func:`~domdf_python_tools.iterative.Len`, and
 	:func:`~domdf_python_tools.iterative.double_chain`
 	moved to :func:`domdf_python_tools.iterative`.
+
+.. versionchanged:: 2.3.0
+
+	Removed :func:`domdf_python_tools.utils.deprecated`.
+	Use the new `deprecation-alias <https://pypi.org/project/deprecation-alias/>`_ package instead.
+
 """
 #
 #  Copyright © 2018-2020 Dominic Davis-Foster <dominic@davis-foster.co.uk>
@@ -33,7 +39,7 @@ General utility functions.
 #
 #  This program is distributed in the hope that it will be useful,
 #  but WITHOUT ANY WARRANTY; without even the implied warranty of
-#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 #  GNU Lesser General Public License for more details.
 #
 #  You should have received a copy of the GNU Lesser General Public License
@@ -41,10 +47,6 @@ General utility functions.
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 #  MA 02110-1301, USA.
 #
-#  check_dependencies based on https://stackoverflow.com/a/29044693/3092681
-#  		Copyright © 2015 TehTechGuy
-# 		Licensed under CC-BY-SA
-#
 #  as_text from https://stackoverflow.com/a/40935194
 # 		Copyright © 2016 User3759685
 # 		Available under the MIT License
@@ -57,38 +59,20 @@ General utility functions.
 #  Copyright © 1995-2000 Corporation for National Research Initiatives. All rights reserved.
 #  Copyright © 1991-1995 Stichting Mathematisch Centrum. All rights reserved.
 #
-#  deprecated based on https://github.com/briancurtin/deprecation
-#  Modified to only change the docstring of the wrapper and not the original function.
-#  |  Licensed under the Apache License, Version 2.0 (the "License"); you may
-#  |  not use this file except in compliance with the License. You may obtain
-#  |  a copy of the License at
-#  |
-#  |      http://www.apache.org/licenses/LICENSE-2.0
-#  |
-#  |  Unless required by applicable law or agreed to in writing, software
-#  |  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-#  |  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-#  |  License for the specific language governing permissions and limitations
-#  |  under the License.
-#
 
 # stdlib
 import inspect
+import json
 import sys
-import typing
 from math import log10
 from pprint import pformat
-from typing import Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
-
-# 3rd party
-from deprecation_alias import deprecated
+from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 # this package
 import domdf_python_tools.words
-from domdf_python_tools import __version__
 from domdf_python_tools.typing import HasHead, String
 
-if typing.TYPE_CHECKING or domdf_python_tools.__docs:  # pragma: no cover
+if TYPE_CHECKING or domdf_python_tools.__docs:  # pragma: no cover
 	# 3rd party
 	from pandas import DataFrame, Series  # type: ignore
 
@@ -111,9 +95,9 @@ __all__ = [
 		"convert_indents",
 		"etc",
 		"head",
-		"deprecated",
 		"magnitude",
 		"trim_precision",
+		"double_repr_string",
 		]
 
 #: The current major python version.
@@ -250,6 +234,8 @@ def posargs2kwargs(
 
 	.. important:: Python 3.8's Positional-Only Parameters (:pep:`570`) are not supported.
 
+	.. versionadded:: 0.4.10
+
 	:param args: List of positional arguments provided to a function.
 	:param posarg_names: Either a list of positional argument names for the function, or the function object.
 	:param kwargs: Optional mapping of keyword argument names to values.
@@ -257,8 +243,6 @@ def posargs2kwargs(
 	:default kwargs: ``{}``
 
 	:return: Dictionary mapping argument names to values.
-
-	.. versionadded:: 0.4.10
 	"""
 
 	if kwargs is None:
@@ -321,11 +305,11 @@ def head(obj: Union[Tuple, List, "DataFrame", "Series", String, HasHead], n: int
 	"""
 	Returns the head of the given object.
 
+	.. versionadded:: 0.8.0
+
 	:param obj:
 	:param n: Show the first ``n`` items of ``obj``.
 
-	.. versionadded:: 0.8.0
-
 	.. seealso:: :func:`textwrap.shorten`, which truncates a string to fit within a given number of characters.
 	"""
 
@@ -354,14 +338,6 @@ def head(obj: Union[Tuple, List, "DataFrame", "Series", String, HasHead], n: int
 		return str(obj[:n]) + etc  # type: ignore
 
 
-deprecated = deprecated(
-	deprecated_in="2.0.0",
-	removed_in="2.3.0",
-	current_version=__version__,
-	details="Use the new 'deprecation-alias' package instead."
-	)(deprecated)  # yapf: disable
-
-
 def magnitude(x: float) -> int:
 	"""
 	Returns the magnitude of the given value.
@@ -369,9 +345,9 @@ def magnitude(x: float) -> int:
 	* For negative numbers the absolute magnitude is returned.
 	* For decimal numbers below ``1`` the magnitude will be negative.
 
-	:param x: Numerical value to find the magnitude of.
-
 	.. versionadded:: 2.0.0
+
+	:param x: Numerical value to find the magnitude of.
 	"""
 
 	if x > 0.0:
@@ -396,10 +372,24 @@ def trim_precision(value: float, precision: int = 4) -> float:
 		>>> type(trim_precision(170.10000000000002, 2))
 		<class 'float'>
 
+	.. versionadded:: 2.0.0
+
 	:param value:
 	:param precision: The number of decimal places to leave in the output.
-
-	.. versionadded:: 2.0.0
 	"""
 
 	return float(format(value, f"0.{precision}f"))
+
+
+def double_repr_string(string: str):
+	"""
+	Like :func:`repr(str) <repr>`, but tries to use double quotes instead.
+
+	.. versionadded:: 2.5.0
+	"""
+
+	# figure out which quote to use; double is preferred
+	if '"' in string and "'" not in string:
+		return repr(string)
+	else:
+		return json.dumps(string, ensure_ascii=False)
