@@ -45,7 +45,8 @@ from typing import Any, Dict, Iterable, List, Optional
 
 # this package
 import domdf_python_tools
-from domdf_python_tools.compat import importlib_resources
+from domdf_python_tools.compat import PYPY, importlib_resources
+from domdf_python_tools.doctools import prettify_docstrings
 
 __all__ = [
 		"greek_uppercase",
@@ -74,9 +75,6 @@ __all__ = [
 		"Plural",
 		]
 
-# this package
-from domdf_python_tools.doctools import prettify_docstrings
-
 ascii_digits = "0123456789"
 """
 ASCII numbers.
@@ -105,13 +103,13 @@ def get_words_list(min_length: int = 0, max_length: int = -1) -> List[str]:
 	Returns the list of words, optionally only including those
 	whose length is between ``min_length`` and ``max_length``.
 
+	.. versionadded:: 0.4.5
+
 	:param min_length: The minimum length of the words to return
 	:param max_length: The maximum length of the words to return. A value of ``-1`` indicates no upper limit.
 	:no-default max_length:
 
 	:return: The list of words meeting the above specifiers.
-
-	.. versionadded:: 0.4.5
 	"""  # noqa D400
 
 	# this package
@@ -136,13 +134,13 @@ def get_random_word(min_length: int = 0, max_length: int = -1) -> str:
 	Returns a random word, optionally only one whose length
 	is between ``min_length`` and ``max_length``.
 
+	.. versionadded:: 0.4.5
+
 	:param min_length: The minimum length of the words to return
 	:param max_length: The maximum length of the words to return. A value of ``-1`` indicates no upper limit.
 	:no-default max_length:
 
 	:return: A random word meeting the above specifiers.
-
-	.. versionadded:: 0.4.5
 	"""  # noqa D400
 
 	words_list = get_words_list(min_length=min_length, max_length=max_length)
@@ -161,13 +159,11 @@ def alpha_sort(
 	"""
 	Sorts a list of strings using a custom alphabet.
 
+	.. versionadded:: 0.7.0
+
 	:param iterable: The strings to sort.
 	:param alphabet: The custom alphabet to use for sorting.
 	:param reverse:
-
-	:return:
-
-	.. versionadded:: 0.7.0
 	"""
 
 	alphabet_ = list(alphabet)
@@ -249,15 +245,13 @@ def make_font(
 	Returns a dictionary mapping ASCII alphabetical characters and digits to the Unicode equivalents
 	in a different pseudo-font.
 
+	.. versionadded:: 0.7.0
+
 	:param uppers: Iterable of uppercase letters (A-Z).
 	:param lowers: Iterable of lowercase letters (a-z).
 	:param digits: Optional iterable of digits (0-9).
 	:param greek_uppers: Optional iterable of uppercase Greek letters (𝚨-𝛁).
 	:param greek_lowers: Optional iterable of lowercase Greek letters (𝛂-𝛡).
-
-	:rtype:
-
-	.. versionadded:: 0.7.0
 	"""  # noqa D400
 
 	font = Font({
@@ -296,7 +290,7 @@ SERIF_BOLD_LETTERS = make_font(
 		greek_lowers=SERIF_BOLD_GREEK_LOWER,
 		)
 """
-Bold Serif :class:`domdf_python_tools.words.Font`
+Bold Serif :class:`domdf_python_tools.words.Font`.
 
 This font includes numbers and Greek letters.
 
@@ -319,7 +313,7 @@ SERIF_ITALIC_LETTERS = make_font(
 		greek_lowers=SERIF_ITALIC_GREEK_LOWER,
 		)
 """
-Italic Serif :class:`domdf_python_tools.words.Font`
+Italic Serif :class:`domdf_python_tools.words.Font`.
 
 This font includes Greek letters.
 
@@ -342,7 +336,7 @@ SERIF_BOLD_ITALIC_LETTERS = make_font(
 		greek_lowers=SERIF_BOLD_ITALIC_GREEK_LOWER,
 		)
 """
-Bold and Italic Serif :class:`domdf_python_tools.words.Font`
+Bold and Italic Serif :class:`domdf_python_tools.words.Font`.
 
 This font includes Greek letters.
 
@@ -362,7 +356,7 @@ SANS_SERIF_LETTERS = make_font(
 		digits=SANS_SERIF_DIGITS,
 		)
 """
-Normal Sans-Serif :class:`domdf_python_tools.words.Font`
+Normal Sans-Serif :class:`domdf_python_tools.words.Font`.
 
 This font includes numbers.
 
@@ -382,7 +376,7 @@ SANS_SERIF_BOLD_LETTERS = make_font(
 		digits=SANS_SERIF_BOLD_DIGITS,
 		)
 """
-Bold Sans-Serif :class:`domdf_python_tools.words.Font`
+Bold Sans-Serif :class:`domdf_python_tools.words.Font`.
 
 This font includes numbers.
 
@@ -399,7 +393,7 @@ SANS_SERIF_ITALIC_LETTERS = make_font(
 		lowers=SANS_SERIF_ITALIC_LOWER,
 		)
 """
-Italic Sans-Serif :class:`domdf_python_tools.words.Font`
+Italic Sans-Serif :class:`domdf_python_tools.words.Font`.
 
 .. versionadded:: 0.7.0
 """
@@ -420,7 +414,7 @@ SANS_SERIF_BOLD_ITALIC_LETTERS = make_font(
 		greek_lowers=SANS_SERIF_BOLD_ITALIC_GREEK_LOWER,
 		)
 """
-Bold and Italic Sans-Serif :class:`domdf_python_tools.words.Font`
+Bold and Italic Sans-Serif :class:`domdf_python_tools.words.Font`.
 
 This font includes Greek letters.
 
@@ -434,7 +428,7 @@ SCRIPT_LOWER = "𝓪𝓫𝓬𝓭𝓮𝓯𝓰𝓱𝓲𝓳𝓴𝓵𝓶𝓷𝓸𝓹
 
 SCRIPT_LETTERS = make_font(SCRIPT_UPPER, SCRIPT_LOWER)
 """
-Script :class:`domdf_python_tools.words.Font`
+Script :class:`domdf_python_tools.words.Font`.
 
 .. versionadded:: 0.7.0
 """
@@ -446,7 +440,7 @@ FRAKTUR_LOWER = "𝖆𝖇𝖈𝖉𝖊𝖋𝖌𝖍𝖎𝖏𝖐𝖑𝖒𝖓𝖔
 
 FRAKTUR_LETTERS = make_font(FRAKTUR_UPPER, FRAKTUR_LOWER)
 """
-Fraktur :class:`domdf_python_tools.words.Font`
+Fraktur :class:`domdf_python_tools.words.Font`.
 
 .. versionadded:: 0.7.0
 """
@@ -460,7 +454,7 @@ MONOSPACE_DIGITS = "𝟶𝟷𝟸𝟹𝟺𝟻𝟼𝟽𝟾𝟿"
 
 MONOSPACE_LETTERS = make_font(MONOSPACE_UPPER, MONOSPACE_LOWER, MONOSPACE_DIGITS)
 """
-Monospace :class:`domdf_python_tools.words.Font`
+Monospace :class:`domdf_python_tools.words.Font`.
 
 This font includes numbers.
 
@@ -476,7 +470,7 @@ DOUBLESTRUCK_DIGITS = "𝟘𝟙𝟚𝟛𝟜𝟝𝟞𝟟𝟠𝟡"
 
 DOUBLESTRUCK_LETTERS = make_font(DOUBLESTRUCK_UPPER, DOUBLESTRUCK_LOWER, DOUBLESTRUCK_DIGITS)
 """
-Doublestruck :class:`domdf_python_tools.words.Font`
+Doublestruck :class:`domdf_python_tools.words.Font`.
 
 This font includes numbers.
 
@@ -561,7 +555,7 @@ The carriage return character (``\\r``) for use in f-strings.
 .. versionadded:: 1.3.0
 """
 
-LF = '\r'
+LF = '\n'
 """
 The newline character (``\\n``) for use in f-strings.
 
@@ -607,7 +601,7 @@ class Plural(functools.partial):
 			:param n:
 			"""
 
-	if platform.python_implementation() == "PyPy":
+	if PYPY:  # pragma: no cover (!CPython)
 
 		def __init__(self, singular: str, plural: str):
 			super().__init__(ngettext, singular, plural)
